function [ Kf ] = Stress_Reduce_Torque_m( Kt, radius, Sut )
%
%   This routine reduces the stress concentration factor using the Neuber
%   equation.
%
%   kt = the static stress concentration factor
%   radius = the fillet radius at the step in mm
%   Sut = the ultimate tensile stress in MPa

%  First we convert the radius to inches and Sut to Kpsi

S = Sut / 6.8948;
r = radius / 25.4;

%  Compute Neubers constant for bending or axial stress

a = 0.190 - 2.51e-3*S + 1.35e-5*S^2 - 2.67e-8*S^3;

%  Compute the new stress reduction factor Kf

Kf = 1 + (Kt - 1) / (1 + a / sqrt(r));
end

